(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     56000,       1297]
NotebookOptionsPosition[     52957,       1239]
NotebookOutlinePosition[     53451,       1257]
CellTagsIndexPosition[     53408,       1254]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 StyleBox[
  RowBox[{
  "Solution", " ", "to", " ", "the", " ", "Friedmann", " ", "Equation"}], 
  "Title",
  FontColor->RGBColor[1, 0.5, 0.5]]], "Input",
 CellChangeTimes->{{3.739781148970622*^9, 3.7397811530716968`*^9}, 
   3.739801522436312*^9, {3.740953380641458*^9, 3.740953380861803*^9}, {
   3.741202889122962*^9, 3.741202889395899*^9}, {3.7418017479524107`*^9, 
   3.74180175134562*^9}, {3.741874370688937*^9, 3.7418743951829*^9}, {
   3.930570900363927*^9, 
   3.930570908047388*^9}},ExpressionUUID->"25dab243-035a-4649-9238-\
32f786e37031"],

Cell[BoxData[
 RowBox[{"Clear", "[", "\"\<Global`*\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.46728913729679*^9, 3.4672891378313093`*^9}, {
   3.542669977824887*^9, 3.542669981705827*^9}, 3.542670043313819*^9, 
   3.73927613358805*^9, {3.739898581724797*^9, 3.7398986148017273`*^9}, {
   3.739898665395369*^9, 3.73989867484021*^9}},
 Background->GrayLevel[1],
 CellLabel->
  "In[270]:=",ExpressionUUID->"728283dd-d7c1-42e6-9c41-1908d357a833"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"friedmann", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"D", "[", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], ",", "t"}], "]"}], "^", "2"}], "-", 
   RowBox[{"8", 
    RowBox[{"\[Pi]", "/", "3"}], "  ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"krad", "/", 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "^", "4"}]}], "+", 
      RowBox[{"kmatter", "/", 
       RowBox[{
        RowBox[{"a", "[", "t", "]"}], "^", "3"}]}], "+", "kvacuum"}], ")"}], 
    " ", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "^", "2"}]}], "+", "k"}]}]], "Input",
 CellLabel->
  "In[271]:=",ExpressionUUID->"fd6a88ed-d728-44d1-85b9-d80478a73835"],

Cell[BoxData[
 RowBox[{"k", "-", 
  RowBox[{
   FractionBox["8", "3"], " ", "\[Pi]", " ", 
   RowBox[{"(", 
    RowBox[{"kvacuum", "+", 
     FractionBox["krad", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "4"]], "+", 
     FractionBox["kmatter", 
      SuperscriptBox[
       RowBox[{"a", "[", "t", "]"}], "3"]]}], ")"}], " ", 
   SuperscriptBox[
    RowBox[{"a", "[", "t", "]"}], "2"]}], "+", 
  SuperscriptBox[
   RowBox[{
    SuperscriptBox["a", "\[Prime]",
     MultilineFunction->None], "[", "t", "]"}], "2"]}]], "Output",
 CellChangeTimes->{3.741875932027855*^9, 3.741876107147877*^9, 
  3.741876946084303*^9, 3.741877163794161*^9, 3.74187723122876*^9, 
  3.741877356940844*^9, 3.741877595500292*^9, 3.741879574763633*^9, 
  3.74187974755909*^9, 3.741885047511485*^9, 3.74191004224755*^9, 
  3.741910313503131*^9, 3.74191065241601*^9, 3.7419106826884336`*^9, 
  3.846145498878815*^9, 3.930570911846752*^9},
 CellLabel->
  "Out[271]=",ExpressionUUID->"6c0a5fd9-c58d-4b2b-a93a-81024cf258fb"]
}, Open  ]],

Cell["\<\
Where kvacuum, krad and kmatter represent the presence of dark energy, \
radiation, and matter respectively. 
For example:\
\>", "Text",
 CellChangeTimes->{{3.74188285333053*^9, 3.741882887404619*^9}, {
  3.74188295618858*^9, 
  3.741882988904984*^9}},ExpressionUUID->"853722f9-ce09-4c79-ab4c-\
12270dedbf4e"],

Cell[TextData[StyleBox["Radiation model:",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Section",
 CellChangeTimes->{{3.741879591432759*^9, 
  3.741879597400751*^9}},ExpressionUUID->"3f5dfcdf-14b6-489a-bc52-\
f7bb2428b055"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["For  a positive curvature:", "Subsection",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Section",
 CellChangeTimes->{{3.741877587331114*^9, 3.741877591901404*^9}, {
  3.741879600072184*^9, 3.741879600896132*^9}, {3.9305709144369507`*^9, 
  3.930570916351553*^9}},ExpressionUUID->"fda42f80-74e0-452c-bdd2-\
b6effa0d3a53"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"friedmann10p", ":=", 
  RowBox[{"friedmann", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"krad", "\[Rule]", "1"}], ",", 
     RowBox[{"kmatter", "\[Rule]", "0"}], ",", 
     RowBox[{"kvacuum", "\[Rule]", "0"}], ",", 
     RowBox[{"k", "\[Rule]", 
      RowBox[{"+", "1"}]}]}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sol10p", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"friedmann10p", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"a", "[", "1", "]"}], "\[Equal]", "1"}]}], "}"}], ",", 
    RowBox[{"a", "[", "t", "]"}], ",", "t"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.7418794661592197`*^9, 3.741879497732508*^9}, {
   3.741879546847659*^9, 3.741879568905735*^9}, 3.741885032263517*^9, 
   3.7419100485986156`*^9, {3.741910129778282*^9, 3.741910134660314*^9}, {
   3.741910685261994*^9, 3.74191068615312*^9}, {3.846145502069317*^9, 
   3.8461455310037*^9}},
 CellLabel->
  "In[272]:=",ExpressionUUID->"80b1b50b-8123-43aa-a9ef-b86add8422db"],

Cell[BoxData[
 TemplateBox[{
  "DSolve", "bvnul", 
   "\"For some branches of the general solution, the given boundary \
conditions lead to an empty solution.\"", 2, 273, 12, 28639881238022721938, 
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.846145531898382*^9, 3.930570918598034*^9},
 CellLabel->
  "During evaluation of \
In[272]:=",ExpressionUUID->"ab8db0fe-9e00-4807-a824-22650a0b3bb1"],

Cell[BoxData[
 TemplateBox[{
  "DSolve", "bvnul", 
   "\"For some branches of the general solution, the given boundary \
conditions lead to an empty solution.\"", 2, 273, 13, 28639881238022721938, 
   "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.846145531898382*^9, 3.930570918618762*^9},
 CellLabel->
  "During evaluation of \
In[272]:=",ExpressionUUID->"a0ec6f3b-d0b3-4853-af52-3a20d80a37d4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[Rule]", 
     FractionBox[
      SqrtBox[
       RowBox[{
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"8", " ", "\[Pi]"}]}], ")"}]}]]}], "+", 
        RowBox[{"6", " ", "t"}], "-", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"8", " ", "\[Pi]"}]}], ")"}]}]], " ", "t"}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["t", "2"]}]}]], 
      SqrtBox["3"]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[Rule]", 
     FractionBox[
      SqrtBox[
       RowBox[{
        RowBox[{
         RowBox[{"-", "2"}], " ", 
         SqrtBox[
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"8", " ", "\[Pi]"}]}], ")"}]}]]}], "+", 
        RowBox[{"6", " ", "t"}], "+", 
        RowBox[{"2", " ", 
         SqrtBox[
          RowBox[{"3", " ", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"8", " ", "\[Pi]"}]}], ")"}]}]], " ", "t"}], "-", 
        RowBox[{"3", " ", 
         SuperscriptBox["t", "2"]}]}]], 
      SqrtBox["3"]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.741885032956945*^9, 3.741885050017279*^9}, 
   3.741910049959341*^9, {3.741910130779491*^9, 3.741910135331129*^9}, 
   3.741910316611767*^9, {3.741910657739765*^9, 3.741910686934603*^9}, {
   3.8461455084186163`*^9, 3.846145532079267*^9}, 3.9305709186444798`*^9},
 CellLabel->
  "Out[273]=",ExpressionUUID->"e6a72c22-e516-4d5b-b33b-56e4638021bc"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["For  zero curvature:", "Subsection",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Section",
 CellChangeTimes->{{3.741877540787318*^9, 3.7418775506696*^9}, {
  3.7418796035042467`*^9, 3.741879603888393*^9}, {3.741884559438323*^9, 
  3.741884559791626*^9}},ExpressionUUID->"239db909-ef68-400c-a3b1-\
f7ff450b449f"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"friedmann100", ":=", 
  RowBox[{"friedmann", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"krad", "\[Rule]", "0"}], ",", 
     RowBox[{"kmatter", "\[Rule]", "1"}], ",", 
     RowBox[{"kvacuum", "\[Rule]", "0"}], ",", 
     RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sol100", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"friedmann100", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"a", "[", "1", "]"}], "\[Equal]", "1"}]}], "}"}], ",", 
    RowBox[{"a", "[", "t", "]"}], ",", "t"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.741877171430552*^9, 3.741877228103621*^9}, {
   3.7418773730067053`*^9, 3.7418773763593287`*^9}, {3.7418774169251227`*^9, 
   3.741877449712869*^9}, {3.741877557145196*^9, 3.741877570790597*^9}, 
   3.741885035855772*^9, {3.741910289820461*^9, 3.741910294460232*^9}, {
   3.846145511754785*^9, 3.846145515346257*^9}},
 CellLabel->
  "In[274]:=",ExpressionUUID->"1f6e2257-d5d6-4e62-babc-1730ee96e56a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"InverseFunction", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[Pi]", " ", 
            RowBox[{"ArcTan", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["3"], " ", 
               SqrtBox["#1"]}], 
              RowBox[{
               RowBox[{"2", " ", 
                SqrtBox[
                 RowBox[{"2", " ", "\[Pi]"}]]}], "-", 
               SqrtBox[
                RowBox[{
                 RowBox[{"8", " ", "\[Pi]"}], "-", 
                 RowBox[{"3", " ", "#1"}]}]]}]], "]"}]}], 
           RowBox[{"3", " ", 
            SqrtBox["3"]}]]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"8", " ", "\[Pi]"}], "-", 
            RowBox[{"3", " ", "#1"}]}]], " ", 
          SqrtBox["#1"]}]}], "&"}], "]"}], "[", 
      RowBox[{
       FractionBox["t", 
        SqrtBox["3"]], "+", 
       RowBox[{
        FractionBox["1", "9"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "3"}], " ", 
           SqrtBox["3"]}], "-", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"8", " ", "\[Pi]"}]}]]}], "-", 
          RowBox[{"16", " ", 
           SqrtBox["3"], " ", "\[Pi]", " ", 
           RowBox[{"ArcTan", "[", 
            FractionBox[
             SqrtBox["3"], 
             RowBox[{
              RowBox[{"2", " ", 
               SqrtBox[
                RowBox[{"2", " ", "\[Pi]"}]]}], "-", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "3"}], "+", 
                RowBox[{"8", " ", "\[Pi]"}]}]]}]], "]"}]}]}], ")"}]}]}], 
      "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[Rule]", 
     RowBox[{
      RowBox[{"InverseFunction", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"-", 
          FractionBox[
           RowBox[{"16", " ", "\[Pi]", " ", 
            RowBox[{"ArcTan", "[", 
             FractionBox[
              RowBox[{
               SqrtBox["3"], " ", 
               SqrtBox["#1"]}], 
              RowBox[{
               RowBox[{"2", " ", 
                SqrtBox[
                 RowBox[{"2", " ", "\[Pi]"}]]}], "-", 
               SqrtBox[
                RowBox[{
                 RowBox[{"8", " ", "\[Pi]"}], "-", 
                 RowBox[{"3", " ", "#1"}]}]]}]], "]"}]}], 
           RowBox[{"3", " ", 
            SqrtBox["3"]}]]}], "-", 
         RowBox[{
          FractionBox["1", "3"], " ", 
          SqrtBox[
           RowBox[{
            RowBox[{"8", " ", "\[Pi]"}], "-", 
            RowBox[{"3", " ", "#1"}]}]], " ", 
          SqrtBox["#1"]}]}], "&"}], "]"}], "[", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["t", 
         SqrtBox["3"]]}], "+", 
       RowBox[{
        FractionBox["1", "9"], " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"3", " ", 
           SqrtBox["3"]}], "-", 
          RowBox[{"3", " ", 
           SqrtBox[
            RowBox[{
             RowBox[{"-", "3"}], "+", 
             RowBox[{"8", " ", "\[Pi]"}]}]]}], "-", 
          RowBox[{"16", " ", 
           SqrtBox["3"], " ", "\[Pi]", " ", 
           RowBox[{"ArcTan", "[", 
            FractionBox[
             SqrtBox["3"], 
             RowBox[{
              RowBox[{"2", " ", 
               SqrtBox[
                RowBox[{"2", " ", "\[Pi]"}]]}], "-", 
              SqrtBox[
               RowBox[{
                RowBox[{"-", "3"}], "+", 
                RowBox[{"8", " ", "\[Pi]"}]}]]}]], "]"}]}]}], ")"}]}]}], 
      "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.741885037100008*^9, 3.741885052115863*^9}, 
   3.741910321142525*^9, {3.741910661642654*^9, 3.741910689481162*^9}, {
   3.846145516390696*^9, 3.846145534822487*^9}, 3.930570924117075*^9},
 CellLabel->
  "Out[275]=",ExpressionUUID->"449cd38a-4355-4153-b1fc-6e4023d7ff41"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["For  a negative curvature:", "Subsection",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Section",
 CellChangeTimes->{{3.741877494751831*^9, 3.741877517415172*^9}, 
   3.741879607408208*^9},ExpressionUUID->"552822cc-57ec-46a7-bce7-\
05be406f3980"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"friedmann10n", ":=", 
  RowBox[{"friedmann", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"krad", "\[Rule]", "0"}], ",", 
     RowBox[{"kmatter", "\[Rule]", "0"}], ",", 
     RowBox[{"kvacuum", "\[Rule]", "1"}], ",", 
     RowBox[{"k", "\[Rule]", "1"}]}], "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{"sol10n", "=", 
  RowBox[{"DSolve", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"friedmann10n", "\[Equal]", "0"}], ",", 
      RowBox[{
       RowBox[{"a", "[", "1", "]"}], "\[Equal]", "1"}]}], "}"}], ",", 
    RowBox[{"a", "[", "t", "]"}], ",", "t"}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.74187752545128*^9, 3.741885039565741*^9, {3.741910298883719*^9, 
   3.741910308063118*^9}, {3.8461455373822927`*^9, 3.846145566718079*^9}},
 CellLabel->
  "In[276]:=",ExpressionUUID->"10edea20-ddb2-4c31-b5f0-894093e8a865"],

Cell[BoxData[
 TemplateBox[{
  "Solve", "ifun", 
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"", 2, 277, 14, 
   28639881238022721938, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7418776081856737`*^9, 3.74187975503969*^9, {3.741885040103752*^9, 
   3.741885054735408*^9}, 3.741910325095076*^9, 3.741910692792821*^9, {
   3.846145540196789*^9, 3.846145568098402*^9}, 3.930570927160828*^9},
 CellLabel->
  "During evaluation of \
In[276]:=",ExpressionUUID->"3e373af9-0966-440c-8fa5-883b2fb1a593"],

Cell[BoxData[
 TemplateBox[{
  "Solve", "ifun", 
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"", 2, 277, 15, 
   28639881238022721938, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7418776081856737`*^9, 3.74187975503969*^9, {3.741885040103752*^9, 
   3.741885054735408*^9}, 3.741910325095076*^9, 3.741910692792821*^9, {
   3.846145540196789*^9, 3.846145568098402*^9}, 3.930570927432436*^9},
 CellLabel->
  "During evaluation of \
In[276]:=",ExpressionUUID->"8074ea3f-c1af-442e-b213-a02a16a86144"],

Cell[BoxData[
 TemplateBox[{
  "Solve", "ifun", 
   "\"Inverse functions are being used by \
\\!\\(\\*RowBox[{\\\"Solve\\\"}]\\), so some solutions may not be found; use \
Reduce for complete solution information.\"", 2, 277, 16, 
   28639881238022721938, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7418776081856737`*^9, 3.74187975503969*^9, {3.741885040103752*^9, 
   3.741885054735408*^9}, 3.741910325095076*^9, 3.741910692792821*^9, {
   3.846145540196789*^9, 3.846145568098402*^9}, 3.930570927751213*^9},
 CellLabel->
  "During evaluation of \
In[276]:=",ExpressionUUID->"180b7458-3c84-4f2d-bb81-ef14eb5dbd9c"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"Solve\\\", \\\"::\\\", \
\\\"ifun\\\"}], \\\"MessageName\\\"]\\) will be suppressed during this \
calculation.\"", 2, 277, 17, 28639881238022721938, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{
  3.7418776081856737`*^9, 3.74187975503969*^9, {3.741885040103752*^9, 
   3.741885054735408*^9}, 3.741910325095076*^9, 3.741910692792821*^9, {
   3.846145540196789*^9, 3.846145568098402*^9}, 3.9305709277585287`*^9},
 CellLabel->
  "During evaluation of \
In[276]:=",ExpressionUUID->"77799151-55f1-4e42-b558-63dc6506af7b"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[Rule]", 
     RowBox[{"-", 
      FractionBox[
       RowBox[{
        SqrtBox[
         FractionBox["3", 
          RowBox[{"2", " ", "\[Pi]"}]]], " ", 
        RowBox[{"Tanh", "[", 
         RowBox[{
          FractionBox["2", "3"], " ", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{
             SqrtBox[
              RowBox[{"6", " ", "\[Pi]"}]], " ", "t"}], "+", 
            FractionBox[
             RowBox[{
              RowBox[{
               RowBox[{"-", "4"}], " ", 
               SqrtBox["3"], " ", "\[Pi]"}], "-", 
              RowBox[{"3", " ", 
               SqrtBox[
                RowBox[{"2", " ", "\[Pi]"}]], " ", 
               RowBox[{"ArcTanh", "[", 
                RowBox[{"2", " ", 
                 SqrtBox[
                  FractionBox[
                   RowBox[{"2", " ", "\[Pi]"}], 
                   RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", " ", "\[Pi]"}]}]]]}], "]"}]}]}], 
             RowBox[{"2", " ", 
              SqrtBox[
               RowBox[{"2", " ", "\[Pi]"}]]}]]}], ")"}]}], "]"}]}], 
       RowBox[{"2", " ", 
        SqrtBox[
         RowBox[{
          RowBox[{"-", "1"}], "+", 
          SuperscriptBox[
           RowBox[{"Tanh", "[", 
            RowBox[{
             FractionBox["2", "3"], " ", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{
                SqrtBox[
                 RowBox[{"6", " ", "\[Pi]"}]], " ", "t"}], "+", 
               FractionBox[
                RowBox[{
                 RowBox[{
                  RowBox[{"-", "4"}], " ", 
                  SqrtBox["3"], " ", "\[Pi]"}], "-", 
                 RowBox[{"3", " ", 
                  SqrtBox[
                   RowBox[{"2", " ", "\[Pi]"}]], " ", 
                  RowBox[{"ArcTanh", "[", 
                   RowBox[{"2", " ", 
                    SqrtBox[
                    FractionBox[
                    RowBox[{"2", " ", "\[Pi]"}], 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", " ", "\[Pi]"}]}]]]}], "]"}]}]}], 
                RowBox[{"2", " ", 
                 SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]]}]]}], ")"}]}], "]"}], 
           "2"]}]]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"a", "[", "t", "]"}], "\[Rule]", 
     FractionBox[
      RowBox[{
       SqrtBox[
        FractionBox["3", 
         RowBox[{"2", " ", "\[Pi]"}]]], " ", 
       RowBox[{"Tanh", "[", 
        RowBox[{
         FractionBox["2", "3"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            SqrtBox[
             RowBox[{"6", " ", "\[Pi]"}]], " ", "t"}], "-", 
           FractionBox[
            RowBox[{
             RowBox[{"4", " ", 
              SqrtBox["3"], " ", "\[Pi]"}], "-", 
             RowBox[{"3", " ", 
              SqrtBox[
               RowBox[{"2", " ", "\[Pi]"}]], " ", 
              RowBox[{"ArcTanh", "[", 
               RowBox[{"2", " ", 
                SqrtBox[
                 FractionBox[
                  RowBox[{"2", " ", "\[Pi]"}], 
                  RowBox[{
                   RowBox[{"-", "3"}], "+", 
                   RowBox[{"8", " ", "\[Pi]"}]}]]]}], "]"}]}]}], 
            RowBox[{"2", " ", 
             SqrtBox[
              RowBox[{"2", " ", "\[Pi]"}]]}]]}], ")"}]}], "]"}]}], 
      RowBox[{"2", " ", 
       SqrtBox[
        RowBox[{
         RowBox[{"-", "1"}], "+", 
         SuperscriptBox[
          RowBox[{"Tanh", "[", 
           RowBox[{
            FractionBox["2", "3"], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{
               SqrtBox[
                RowBox[{"6", " ", "\[Pi]"}]], " ", "t"}], "-", 
              FractionBox[
               RowBox[{
                RowBox[{"4", " ", 
                 SqrtBox["3"], " ", "\[Pi]"}], "-", 
                RowBox[{"3", " ", 
                 SqrtBox[
                  RowBox[{"2", " ", "\[Pi]"}]], " ", 
                 RowBox[{"ArcTanh", "[", 
                  RowBox[{"2", " ", 
                   SqrtBox[
                    FractionBox[
                    RowBox[{"2", " ", "\[Pi]"}], 
                    RowBox[{
                    RowBox[{"-", "3"}], "+", 
                    RowBox[{"8", " ", "\[Pi]"}]}]]]}], "]"}]}]}], 
               RowBox[{"2", " ", 
                SqrtBox[
                 RowBox[{"2", " ", "\[Pi]"}]]}]]}], ")"}]}], "]"}], 
          "2"]}]]}]]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.74188504019442*^9, 3.741885054816364*^9}, 
   3.741910325233021*^9, 3.741910692932508*^9, 3.846145540312341*^9, 
   3.846145585026224*^9, 3.930570931888772*^9},
 CellLabel->
  "Out[277]=",ExpressionUUID->"ed552f91-2871-4bab-a69e-f1da65784144"]
}, Open  ]],

Cell["\<\
Something unusual happens here. Mathematica responds with two different \
interpolating functions, one for each sign of the derivate. Looking carefully \
at the arguments of the functions you can  see the first root corresponds to \
an expanding model, while the second root corresponds to a collapsing model. \
While the latter could be used to represent a \[OpenCurlyDoubleQuote]big \
crunch\[CloseCurlyDoubleQuote] model, we are here interested in the first one.\
\>", "Text",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{
  3.741885021583774*^9},ExpressionUUID->"5afbdf49-b8c5-4209-914b-\
1674e53cf21b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Graphics:",
 FontColor->RGBColor[1, 0.5, 0.5]]], "Section",
 CellChangeTimes->{{3.7418822225192227`*^9, 
  3.741882224389545*^9}},ExpressionUUID->"9ce08758-9c0f-45f2-90e3-\
e8f3b7f28250"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], "/.", 
      RowBox[{"sol10p", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ",", " ", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], "/.", 
      RowBox[{"sol100", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}], ",", 
     RowBox[{
      RowBox[{"a", "[", "t", "]"}], "/.", 
      RowBox[{"sol10n", "[", 
       RowBox[{"[", "2", "]"}], "]"}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0.85", ",", "10"}], "}"}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Red", ",", "Black", ",", "Blue"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<t(s)\>\"", ",", "\"\<a(t)\>\""}], "}"}]}], ",", 
   RowBox[{"PlotLabels", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<Radiation\>\"", ",", "\"\<Matter\>\"", ",", "\"\<Vacuum\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.741875359741618*^9, 3.741875386779614*^9}, {
   3.741875852310634*^9, 3.741875852577899*^9}, {3.741876158404427*^9, 
   3.741876158562583*^9}, {3.741877195244066*^9, 3.741877205368209*^9}, {
   3.74187724192192*^9, 3.741877249619448*^9}, {3.741877324161758*^9, 
   3.741877367158513*^9}, {3.7418791201983337`*^9, 3.741879132830687*^9}, {
   3.741879188363158*^9, 3.741879274182237*^9}, 3.741879306519177*^9, {
   3.741879637854173*^9, 3.741879642207161*^9}, {3.741879702786455*^9, 
   3.741879739863752*^9}, {3.741879771012907*^9, 3.741879776030462*^9}, {
   3.741910093859449*^9, 3.741910112923274*^9}, {3.7419102216243153`*^9, 
   3.74191028004823*^9}, 3.741910368590575*^9, 3.741910675570068*^9, {
   3.741910713686945*^9, 3.741910718014048*^9}, {3.84614555810458*^9, 
   3.8461455583805513`*^9}, {3.846145620946649*^9, 3.846145646369306*^9}, {
   3.8461456930164943`*^9, 3.846145704276539*^9}, {3.8461457578582907`*^9, 
   3.846145761518258*^9}},
 CellLabel->
  "In[278]:=",ExpressionUUID->"4747573b-aa3f-41d8-bb6f-161a826d00bd"],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    TagBox[
     {RGBColor[1, 0, 0], AbsoluteThickness[2], Opacity[1.], 
      LineBox[CompressedData["
1:eJwV13k4lF8bB/CZMfOMZVZjmZksJVvaLEUU566UraKkFPpRqSTZs7SoJAqF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       "]]},
     Annotation[#, "Charting`Private`Tag#1"]& ], 
    TagBox[
     {GrayLevel[0], AbsoluteThickness[2], Opacity[1.], LineBox[CompressedData["
1:eJwVzH1QiwEAx/G8JWZXht1Cwnnp1ZUVxey3Ox1d5GXz3umiJckxxDVnsS45
Ut6m3NGq5SWGSdkK3VnmrZe1RG+r9EbT2tOz5zHylpc/vvf57ztr535h3Egn
J6fAf/13/ttDOVyuFXekuvHqfgd49fqqgAgr3I5XT1GZHBCaXIf9d1hhsESd
TNc6kGJUi73OWSGOMLSzUx1orOoJ9LBaoZ+Rvm0dx4H056Ia58IB3F/JJH8I
vqC3lDuilUUgtkPCzZVT+FEiD2ryJhC5f11jk5iCW0ld/DsBAXNZ/+qhlRR4
xYlG4z4CoaHl8Z+ZFBT3Cq8+ryLQ/n3tm9Qrdiy/OWnRvdRBuCwr/MwvIlFf
LQ0WSEmovl64nbjdhpghT5H2JImk3zK9L9sGYs5Lid9FEjNm6fadNg5gQgrr
LkdNovjy/NdT+AMID1DPtreRWJhnCgjhWPFM0eaqEthxI3pM1BmtBWv1qf6c
SDu8gy7ddd1tQYfNa1XWVjuUW1nB49wt+LXicPrRg3Y8uSjfECHtQ8h35m/h
dTtOR5/KViz8BM129I9yoaDrivw1Nq0H/DMfxx6dTOGxeZh3y6cHNdqMueRM
Cq1l9bWxpm70uzbHtIVSkK/P/DbRvRvzKiVNpYkU3ueLRd7KTjwi2A6fZArx
6pfOubxOhE2rYBWkUbia5qm8XfIBO5PGrcnMpZAfaK0tmNkB5TyVIa6OwqV8
5ZwXja3wF4V3m80UKvt8H77+2YKnx4k/6y0UTIZzDPv0FrQ2L1nKH0GDRzJ8
zwubkDCma0spk0aff29Q9K5GDAWeOuIzlYaNKor/mfQe7IyGYjaXRqcLoXlw
ogE3dNK6s6CRsLEoLOfYWwT1etpGrv7383AXtUvqIVy212tQTEPgxstgyIzo
SmCtiDtAI3lH2LDMpwaS7LJYs4xG3iHx+ZyKN8gcHJ33KptGTLafKU9mAOfO
to17VDSCRZOynKv1UIkfMJj3afAnDF+TP62An6dzpaacBmPT5oKUJTpoW6KS
hS9o1I6fFpK1WAOBoniBw0RDLYw5MspDgYzyyoHwBhqqZg9NXPsB/AWhlZOr

       "]]},
     Annotation[#, "Charting`Private`Tag#2"]& ], 
    TagBox[
     {RGBColor[0, 0, 1], AbsoluteThickness[2], Opacity[1.], 
      LineBox[CompressedData["
1:eJwVV3c4Fv4XfXlf28s7lIyQslKSEkV9jhZRUREVhag0REZUJKuSrJCRiERK
VimjIqOSFFkpI/Ele4uMn99f949zz33ufe7znOecZdbn99tyUigURw4K5f9V
ocbp7rp1vUT0oXxa1b1Ool1dXKGq30uC6p/NxZR0kv1fhedWW/USWse9c2U9
ncSz6omNYnAvGXj2UEdj03+kvuL32qW9vcSy1iP9QfN/xL/kQCV3Uh/xvbLl
oIpGN7n37sE8Nb+PFMi+0V1j002yiwfVOKr7yGeLvIzo0G7S8vZW9L+5PhI/
azuR3t9N1AtLTgwd7ieJecn6PWl/SMfzdRxNrAEytNrs2slNvWQ659r6BqUB
IjyZ23vMvpcwcr6crMUAsdqnP1yV2Eu0s85UVdkPED3lvsMi9D4Snp4UW1Ix
QKaSeMdMuvrItkfsDenegyT8RtgFv5wBUv3JXR3uQ2QqJHT0g9kwsfwrfSDX
b4jkl7tMcXkOk4EV5Q6rwoaI6HjM79ikYSLoyXq65MkQWdbjYF03OEz0VJ/I
Dv8cIrRt24+FB46QovCfwokYJu2JFXyjDaPEsNh79ZI9wyT0r9xPCeoYaelX
NAg6NEymNQYs01TGyMxOF/9LF4ZJSs2aqX/+Y0Rzij67/+EwkbY2lwjQHicZ
FqSHyjtChnZyVkgVTpAtAZ08l0RGSOSWriXCAxOkMveW3JDMCHGaFRhwkpkk
PcKNlj83jhCZ0bLV8f6TRP6dQ8PzMyNEwTA6OsrsL7kvn1hq+2WEYOX591SR
aXJ7kBb/PnKUTDLGHzwamiVL0g6bnE4cJfPRNeONKnMk0SZTgP5slKx70UsN
PTdHcr8fcdtfNkoejqalRvbNkbaS7H3No6MkVEKYLjo8T9SiLGmjRmOkJ895
yoWfA4X7c/MjzMdIV1H/c4oKB3Tpgo6ap8aIhTAlqGEfB8y9XzZ7XB0jWuvP
LDobwwG/s0IveZ+NEdHTWcpb13CiEYV2UgLjZNMj6VvrT1Fh/Y8pU7x4nCSu
vB5QFUJF34uT9cdlx8n3yIKNb/Oo4FBmb3u8cZyctov1TBGkYeWi05LrT40T
L2+h7ym5NHj8Ef2yq2yc7LVyTBOS5IZsmNN6l6sTxKPHlY9TjQ8U2ztXmgMm
SJKAdGanLR9aNHJKd0ROEI7lrzzVY/gQ0zxivDh9gmwzvc9YSuMHU+mCy8um
CfL9RmnDimZ+UIoccqfUJ8mdhLvxvx8KoiUsZM5KZ5LEL5/ZNtEqiELbzJ0V
uyfJEGJbfCTocBMYqo85PkkKl1IH2eF0DB08P6kVOkl2+K4vXH5LCK395zQ9
+yaJj8Rn73E9BgqLbnv9NzlJ0uc+6IafZiDmTvqHvdS/pDt93bhbIAMHN/ab
SYv/JYKzdQaLqxmo8j3rXqT7l+zomv+XacHEG4kz+ZxJf0mYlASl15eFe7tO
aV8/NEWk7u3b/V14ETx3Xeftsp0inv5dTWJkESx3PardeWGKhB41aiu1X4QV
uzrOct+aInplcvSjXxbhiZ5lnF/hFOkQsA9/GbEY+bpmcz7S06TIaib9t8YS
3NO9WPFbeZpwFTqYw34JPHUjI7dpThOFE+auoslLsFW3VoW6b5rYT2zYtFFE
DB93Gh3z9p4mxzNqH9v9FUPjDr0ir85p0h6sk3j5uwTyd5wMbBueJls+Ld/F
tUQS93b4m2FumrgoheRKmErCckfp0Pzif4SXYtQ4Wi+Jru1YdlXvH4l75XjZ
uXkpJrZpens8+UeUvvicOUeVAXur4vZLjjOkpEVq+5XTshj6MpHK7TFDZrrv
5y4OlUWVRRn9zo0ZkrUyaC3nK1nccLdueBI/Q7w+h/6p4l6Oucx7p5s/zxD+
ZS/27k9djm5pZihWzpIHS0MF4/6tQFl663il+iyZvB9fHqMgh0StZ4cP6cyS
pk2xtWMH5GBharDigtkssVLSGCtKl0NNkN/LJP9ZssUwtabKVh6Fs1PN3L8X
+rPMxi90KyD61oetdwZmSdK4uVa4uCJcxe6mSE/PEme1A8+l9ihirfp6R03m
HDlcopFzIUcRj87a006TOdIY03VxjZ8SQn60r/wcO0fUMmS+l29Whm3ep4t3
jOfJOtuqbSv512Cnc7SlqNU8aU+xaigwWgPFNSd3xZ6bJ79vKg32312Dnoec
Ekn+8yRlj1KWpIgq7EM2vsl+NU90TIJ5DFJVUZhzgNNOiILU3G0pP9rWYlVo
/kSaCAXzRe7F1/jUEGe/rLdPnAI1CWkjXzU1eCoNfnNQoMCTdnZRop8adOID
kt1AQf9q7+emqutQHlCsd+MCBcQva/u5qPXYcEpxc4UbBfeb04/rvF+PlB3B
awWvUiCzVIbmNbEeNygW4iG3KKhM0gjHQXUYuP7tvfuQAtuLVyb+iG/AV6s1
wSn1FOzxjtV5naeBJs24uvJNHBj/cL+62VgLzrJ/wnrBAf+oK3ZtoVoQFlQ3
Yuhy4HqOlMaZL1rY3lpZcegAB0w0AjdI7dZGut/M274zC/0KPzMkdm+GV82R
NFbcgq79NfwVeJJAvDDlpEYSBwL+izqQkk7wInl0hfnjBX4NRe/oGEGP2634
5BccaBxvvPtNBzCWLgjXrOKA2x61qc5aQOGs+NWj8xwQieHNqubfincmJ7R9
uDghupZtsGTdVpiT7KkUAU48c7375dWRrQhh6TsPi3KC7Ewv5H+2FdOv3O18
VTmh3mwWwGu6DVVc3w+kWXHieORaqlzBdjjH31WcKOFE3NvWIKEaXQgaaall
feSEY/v6Pw+penhIadU6+4UT6YlfPBPV9VBrJW/Y3sSJ1y7KefUxelBf8cKl
apgTdTv9Dmud3oWJ1Jp3j6QXdPrK1Jv8pQYIOuRaaSVHxcT+Y66rDxpAnl+8
XlKZiovxelmLgg1w8IzVn7ANVJjkKfjrc+7Gy9VDwlf3UPHg1Vyv5cBuuGXT
LUwvU5HnrX9qWcteMI5nnWBdo2Lri9jLx6UMkco2cfjsT4XrUKCx8jFDNDrf
89kWRsWuz245Ru2G2KihnLbmMRWa3Dsjblw0wnSB3iRPAxX3PdeceR66D5fL
fEJfqdHA0jn2ZGr+ACIFFSwGNWnQazunsXy1MTIPVCjKExq6BY+/zT5sjI5f
jKI7BjRsjNc+yvPSGLvn4gbsbWhYlPPlRoKzCSQ1XhnIRdJQ8PoT10maKTZ4
HhE1v0cD9emJektNUxiVzbWHJdKQwZPD9fWsKXwP7LhEyaBhS3/9I1aDKfrP
16T+eE/DaH+l784sM7xJ7eMKm6Lh/GbRtRYeh9E4GFz9YZ6G5DspZ1XyDmNk
w7q4eS4u7NTuKfAfPwz5Mvf151hc0C83Na8+fwTBv7iP6ylzQbJzw9Oh0+aw
FF9WNGfOhcdrlPodrhwFR6DJpTNFXEh3Wz4/EGCFJTFGYZrlC3iHXWBXhhVU
Uw3SuCq5kOO9gqZSZwXLUp2m+AYukAeaO1JkrFE0s3pT7QAXcrUMDlkUWMPz
HPe09lJuSFiqvLan2CDyMgeLfzk3SkxOjUWstMGzmzNKDYrc2CNF51xsYoPm
5JFDjuu50dDcGbT8iQ20W1rykg240cSSMbh5xBbTe1+6C13ihpv7ttPKVSfA
ssgO/XGVG9Q3m3W05k5g5Zn0x6l+3Hgkcs46U+UkDl1P+r41lBtFfdQfn0NO
4tXb4I0XU7mhYD17rv/QKbiqnppqredG4Np4Ux/KaYwyxdyz1vHgnaRDWkjy
OaxfNXXIaiMP+GzUHnxpPwfXnd83MQkPfn+7IHVbxh7Tl6JnHPR58JjrVOn1
OHtQOsS8VK140Cfo0RQVdx6CueLXM4J40LrMSer2Dwfs/Tp98lg4D9wLOs9b
zjkguKdJTziGB/5uSjmXlzmCJR3Lfz6ZB0nJddaBpxwhdkMiSKWQB15MjzH5
aUfIH5aMSP/DA6ev4ZYflZ1wynnGxWKQB8pus8o2B5zwOOjnQfo4D26nZX4w
uuyEVSX3lpyj8IKtXCghW+kEtVVL760S5UXv0+bpl47OIHNLk55s513wBTzf
DT67wCxROutxPC9aaKbftD65QfLA/IG6ZF5kqS+v+cbpjlZq6wTlKS9Ev9xx
697kjhO297XNXvGCr3eVZOBTdzgrLv3AXc2LT+JjfT8iLiH0mXjrcU4+1MZP
usZfuwLjY9PXgnn5MGZ+zSWg+AqWMJpWFAjxYZG5XRmN0wMJjtGnWRJ8uKw9
Zv3U1wPP1i+ZKFrHh0d9B8/2hniiIn8RXWrBh/00pt9UPO6FoDPjGbvO8KF7
jQSr67oX9knW7Xdx5EPAisXzk0+90OgRHlXpwQefx8+72X+98B/YKy5H8mHn
56AIvbBroL5naDW+50NQlXuOYYM3tL8J2IWt5MfKE7xzvo/9MKu/zcxYlR/p
Hit7v9X74c27S7qLN/Bj4krevWs0f+hk/5GL0eHHrlzayRlLf+wMfd/+wIwf
x8x9nvhJXYeRoY95lj//wl03JOOe3gDzfb6BUyA/jr+dbNRsu4GaLSOb1MP4
oVm37DpEbsJExUosL44fKUkXdO563MRhOqkves6P7rW39102CYDNp2nDr+38
qPY3P9IvHgi5bWokrJsf8fmblXJNAvFfvp2K8QA/Uu8f7Z0KCYRdWqNg4xQ/
QjZY7p/gvQ37m7kfWxkCqEwr3NM6dxtuuhe2DW4RgLNEjXIGRwhul/zZIBQr
gHhfngwXrTB8rZbpNnggAJ1VXse/2IRBpM00+maKAKQHdVv9g8IQM1P2j/Zc
AEX9Zb6s32FIUU8s+lcpAJ46E53nIXdQnHJY/8+cAPgOXi3onAsHLTf0nzyX
ILwbCn77qERAr/TDUxsBQVzm0RIIOhqBqrYNwm2igiiqqFjd8zYCP8TYtfWq
gjiPOGbz9UiM3/pkUWotCOXHDubBq6OgGcMpzGknCBnRg0q2NlG4krqxiJwX
RJ3pyIGXsVHgLEuRLbgsiA8xeQp1AtEQnvPpygoXhMoK50OLR6Kh5KDtGF8u
CBO7MqGchlhYGKf7XlpJR+rP+lEqbwIq7D/OxajSsXqpd91z5QRo3ux0K9hA
R3x/6+oXhglgvVl6bmYrHb4d2rSUqASUKwSZeB6hQ0baiHpc5QFU/tnLewfS
cf6q0+lWu0TELrqVkBhGR3/9fv6WsETwqqaIl0TRIZKqNKhRmIh2m1YhWjId
A+nKLymMJERWGU76vaYj6Une95mCJMw9UP1wc4CO22+OfD8sn4wzhbu3po3R
0bLv1V8Hk2Q01p8qrJimQ3ZWYnjQNxnZAg8yBXiEYNqiNK/cmYwTLszo29JC
uF1pkpeb9ghVeiN2oUZCWHPAs7xfPxXxgzkC0dlCKMhjzgp3PQF/tUKN4Ssh
FGpdfjct8xTO2bFR3G+EoCDDLLQ48hT6Lj5yzh+FcEhun3ZI9VOMTe8nhm1C
SOly1C0pSYc+98gFLiFhlLvSs3YWZeBFl+3GQrYw/DZKaIlyZELm4/f5C2LC
KBAd8zGUzVz4b3Fg2wphFOZRrgTbZiKBGfqoQEsYL0yH+80HMzEhqdrkaCeM
pJ8ZGpmMbFjNJSUonhfGqFfh/TUbslHZKnqy1XlhHs+Zxpkj2XiQOD+620sY
J4UXHfJJzcZuxS90xbvCODY5dGb/jhwkrrPXaSkVRtaf/IDbQc+hIHfQWI7B
QH1g70Zbm5eQ+hUctYW9kLO0/fzY0S8hEvfxp+liBrilb7hpVr0EZdFm2wBJ
BsLFqMd6Nr5CE22F66AiA2d2lYcLiuYhsGP4bp4OAwa9S9fiTz68E5R/1mxn
wEjGe/8PuQK4m9vK9OkyYKx7sWPOugAnahtTpfYywKdG29vRUgBS+jbP5zAD
5yc5zus3F2Ik6faPPU4MbFPoEEwYf4PuY++lT7oyQP+syHVI6y1aJThsvNwZ
KEoNYmdce4vKO8592VcX+EOyUxK8RUj2OTIrupAL333zfOoYUwSz40rS7Q8Z
GJczyhmtKsYb2TJr13oGJptzPcuulGLdu5WfD39ngN/x+9ualFKkWoVokJ8M
vOa37tj0rRR3Eo4I8rYzkCuqOiWpXIZTUiMvovsZeGhiNkNay8ASl+Z7TWPC
neq3LvPQe1zP83V6wMNEFDMnsjjgPWbMepr9+JmgVWUZbyp8j667L7L3MphI
XqXuZiPzAYWLdpu3STCRVJOQmdP/AbZM9wzqOiYSot4t4o6rQFNmi1i3OhO6
KYEfR2orYGS03bdSk4n7HPUXTeifsClY+FDEFiYsdK8KXL36CUL0R5wK+kwY
/DFI9rSrxCvebyb6Vky4+lJ6FptUQZCyeiYkmInl7Sd6xXZV493pMN2cMCZE
8z3fuDtUw61uMqwugolB0bQJtahqdKa9UxK/x8SVlJ/0F93VeGNiZpqUysTf
szEC7KAanH/ik/2imImGfbkPu3u+QX7xn9mG0gXc+wVbd0ktfnrt3TX9nomB
yKFl9J210Dso1raliglOj+Tc6sRayHBk0D80MRGqtdnIwqoONQebTjWNMhHn
1H1332g9bhST5zMTTJg4VZAohQZsWZU8LzXNhHQza8lB8wY84XCIPE5hweAo
85r2+wb4PuUq7RNkwapNaPxTYiM2cK6VnpdjoYShemTUsQnR6dfrlpuxcNFm
9thXtxbY3D/mp3GEBY5b4R9HClugGqyhbnCUhUwNsaQsjlaUO3SFX7BhwcVb
OONvYCtG1ukaFzuwQGL4ehxN2qCfz/3t6E0W4ppLDV57/8KiJy3eFwJZ8CvV
TOx8/Attsblq/sEsjC4Jn7Ct/gVXjxNh6REsLH/xYvDcsnYkoXzfzAMWFOty
WK/L2jFT7vc1Op+1oJvGnpwyHXj/0sIr/TUL0+PDFzn2dCAsVV21uGhhn+QV
kXaXOqAY0BncXc7CHw2FtBP1HTDZs8NQ4xsLohMW5RvvdOLZN1pVbS8Lw7cP
vt+wrAuWbT6fhJey8emZ+D+tiB6kPb/+YECaDb7dv3QyKnswduPWxc+ybPyK
1VYPpfXixto7y28psmGZU/z5tUsvMr0TL3OvZ2Nv/RbZeIs+zK8oVp7VZ6Mg
Iu912PYB6E2Vcvzcw8YJj+LYHJ8BhH3+0JBvxMZHz0GOwyUDkHf96uN2kI32
Z19FV24fxN73rT9Grdg4+0RUSVx+CPft5m71uLFhKJbIZaI1jO7NnNYfL7Ox
ylX8of6xYaixuDVTPdmwu6+3w8tnGOX59A5bXzYcfR/yNFUOY0BgqfavYDbM
0gOdVh8fwZZnWn0Njxb45lYPvt8fRfOI2+6yWjbe/R6ZFTGdwKmwK9T2Bjau
NwxPJ9ycwMhar/y5JjYaTuz5GF04AV7H64qav9jI/tQWMb58EusHI2hP+tlo
cR+qFfs7icDe7MIQbhGs0p794fRyCqK3cp3S+URwRV8rP2t4Cokr81dWCIpg
xQ6nGfNV03hlVxxFZYvARjTcUy1pGh1dX5xdpUWgIZug63/3H7Q6+laZa4pg
x17JewExsyj3GfrtpiWCQltZFePmWRgtH4uJ2CIC5uAVMf5lczhh/Y/3y3YR
rLa/WPz78RzC2vg6dfaJwHq2kY9eMo+en/JxCqdFEH6u+M8AH4dOxm6TQOUA
EbiozqjWZHHq/A8nY46T
       "]]},
     Annotation[#, "Charting`Private`Tag#3"]& ]}, {{{}, {GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{3, 0}, {6.610490331217681, 0.022163759678133443`}], 
           Offset[{1.1183868172842262`, 2.783740456099465}, {10.373625, 
            0.022163759678133443`}], 
           Offset[{0, 0}, {10.556625, 12335.636201218978`}], 
           Offset[{5., 1.1102230246251565`*^-15}, {10.556625, 
            12335.636201218978`}], 
           Offset[{10., 2.220446049250313*^-15}, {10.556625, 
            12335.636201218978`}], 
           Offset[{10., 2.220446049250313*^-15}, {10.556625, 
            12335.636201218978`}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{3, 0}, {6.610490331217681, 0.022163759678133443`}], 
           Offset[{1.1183868172842262`, 2.783740456099465}, {10.373625, 
            0.022163759678133443`}], 
           Offset[{0, 0}, {10.556625, 12335.636201218978`}], 
           Offset[{5., 1.1102230246251565`*^-15}, {10.556625, 
            12335.636201218978`}], 
           Offset[{10., 2.220446049250313*^-15}, {10.556625, 
            12335.636201218978`}], 
           Offset[{10., 2.220446049250313*^-15}, {10.556625, 
            12335.636201218978`}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{58., 6.000000000000012}, {10.556625, 12335.636201218978`}], 
           Offset[{58., -5.999999999999988}, {10.556625, 
            12335.636201218978`}], 
           Offset[{10., -5.999999999999998}, {10.556625, 
            12335.636201218978`}], 
           Offset[{10., 6.000000000000002}, {10.556625, 
            12335.636201218978`}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"Radiation\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{34., 7.549516567451064*^-15}, \
{10.556625, 12335.636201218978}], NCache[
         ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
          ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{3, 0}, {1.2390832184279101`, 0.004361531451527652}], 
           Offset[{2.8266831838164466`, -1.004918990928779}, {10.373625, 
            0.004361531451527652}], 
           Offset[{0, 0}, {10.556625, -1761.8823864754293`}], 
           Offset[{5., 1.1102230246251565`*^-15}, {
            10.556625, -1761.8823864754293`}], 
           Offset[{10., 2.220446049250313*^-15}, {
            10.556625, -1761.8823864754293`}], 
           Offset[{10., 2.220446049250313*^-15}, {
            10.556625, -1761.8823864754293`}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{3, 0}, {1.2390832184279101`, 0.004361531451527652}], 
           Offset[{2.8266831838164466`, -1.004918990928779}, {10.373625, 
            0.004361531451527652}], 
           Offset[{0, 0}, {10.556625, -1761.8823864754293`}], 
           Offset[{5., 1.1102230246251565`*^-15}, {
            10.556625, -1761.8823864754293`}], 
           Offset[{10., 2.220446049250313*^-15}, {
            10.556625, -1761.8823864754293`}], 
           Offset[{10., 2.220446049250313*^-15}, {
            10.556625, -1761.8823864754293`}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{44., 6.00000000000001}, {10.556625, -1761.8823864754293`}], 
           Offset[{44., -5.99999999999999}, {
            10.556625, -1761.8823864754293`}], 
           Offset[{10., -5.999999999999997}, {
            10.556625, -1761.8823864754293`}], 
           Offset[{10., 6.000000000000003}, {
            10.556625, -1761.8823864754293`}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"Matter\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{27., 5.995204332975845*^-15}, \
{10.556625, -1761.8823864754293}], NCache[
         ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
          ImageScaled[{0.5, 0.5}]]]}], GraphicsGroupBox[{
        {GrayLevel[1], AbsoluteThickness[4], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]], CapForm["Butt"], JoinForm[
         "Round"], 
         BSplineCurveBox[{
          Offset[{3, 0}, {5.134931748110076, 153146.2739185129}], 
           Offset[{3., 0.}, {10.373625, 153146.2739185129}], 
           Offset[{0, 0}, {10.556625, 153146.27391851228`}], 
           Offset[{5., 1.1102230246251565`*^-15}, {10.556625, 
            153146.27391851228`}], 
           Offset[{10., 2.220446049250313*^-15}, {10.556625, 
            153146.27391851228`}], 
           Offset[{10., 2.220446049250313*^-15}, {10.556625, 
            153146.27391851228`}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], 
         BSplineCurveBox[{
          Offset[{3, 0}, {5.134931748110076, 153146.2739185129}], 
           Offset[{3., 0.}, {10.373625, 153146.2739185129}], 
           Offset[{0, 0}, {10.556625, 153146.27391851228`}], 
           Offset[{5., 1.1102230246251565`*^-15}, {10.556625, 
            153146.27391851228`}], 
           Offset[{10., 2.220446049250313*^-15}, {10.556625, 
            153146.27391851228`}], 
           Offset[{10., 2.220446049250313*^-15}, {10.556625, 
            153146.27391851228`}]}]}, 
        {EdgeForm[None], FaceForm[{GrayLevel[1], Opacity[
          NCache[
           Rational[2, 3], 0.6666666666666666]]}], 
         PolygonBox[{
          Offset[{52., 6.0000000000000115`}, {10.556625, 
            153146.27391851228`}], 
           Offset[{52., -5.9999999999999885`}, {10.556625, 
            153146.27391851228`}], 
           Offset[{10., -5.999999999999997}, {10.556625, 
            153146.27391851228`}], 
           Offset[{10., 6.000000000000003}, {10.556625, 
            153146.27391851228`}]}]}, 
        {RGBColor[0.6666666666666666, 0.6666666666666666, 0.6666666666666666],
          AbsoluteThickness[1.25], EdgeForm[None]}, {}, InsetBox[
         StyleBox[
          RotationBox["\<\"Vacuum\"\>",
           BoxRotation->0.],
          StripOnInput->False,
          LineOpacity->1,
          FrontFaceOpacity->1,
          BackFaceOpacity->1,
          Opacity->1,
          FontOpacity->1], 
         Offset[{31., 6.8833827526759706*^-15}, \
{10.556625, 153146.27391851228}], NCache[
         ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
          ImageScaled[{0.5, 0.5}]]]}]}}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox[
     TagBox["\"t(s)\"", HoldForm], TraditionalForm], 
    FormBox[
     TagBox["\"a(t)\"", HoldForm], TraditionalForm]},
  AxesOrigin->{0.8500000000000019, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImagePadding->{{All, 76.4}, {All, All}},
  Method->{
   "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        (Identity[#]& )[
         Part[#, 1]], 
        (Identity[#]& )[
         Part[#, 2]]}& )}},
  PlotRange->{{0.85, 10}, {0., 153146.2739185129}},
  PlotRangeClipping->False,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.08090169943749476]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.741875388147723*^9, {3.74187546927273*^9, 3.741875541364673*^9}, {
   3.741875573487496*^9, 3.7418755911450443`*^9}, {3.741875807432762*^9, 
   3.741875853703167*^9}, 3.7418759379614487`*^9, 3.7418761592485647`*^9, {
   3.741877207473537*^9, 3.741877250672438*^9}, {3.741877330265157*^9, 
   3.741877367593812*^9}, {3.741877425518968*^9, 3.741877456149045*^9}, 
   3.741879133416659*^9, {3.741879189034285*^9, 3.741879275532238*^9}, 
   3.741879306790082*^9, 3.741879717048869*^9, {3.74187976060021*^9, 
   3.741879776810606*^9}, 3.74188505745681*^9, {3.741910098011202*^9, 
   3.741910114126458*^9}, {3.741910232453557*^9, 3.741910254891048*^9}, 
   3.741910330431862*^9, 3.741910369336079*^9, {3.741910677140424*^9, 
   3.741910718333508*^9}, {3.846145544986992*^9, 3.8461455596473093`*^9}, 
   3.846145596341962*^9, {3.846145636258095*^9, 3.84614564771979*^9}, {
   3.846145695036586*^9, 3.846145706140265*^9}, 3.846145765089063*^9, 
   3.9305709365938663`*^9},
 CellLabel->
  "Out[278]=",ExpressionUUID->"67ab3557-a397-4ac6-bbcf-7de88dfa6181"]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1462, 772},
WindowMargins->{{Automatic, 1}, {Automatic, 0}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
Magnification->1.5,
FrontEndVersion->"14.0 for Mac OS X ARM (64-bit) (December 12, 2023)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"c6a6417d-9aeb-4cc8-82b4-5c52eb826e45"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 564, 12, 106, "Input",ExpressionUUID->"25dab243-035a-4649-9238-32f786e37031"],
Cell[1124, 34, 444, 8, 46, "Input",ExpressionUUID->"728283dd-d7c1-42e6-9c41-1908d357a833"],
Cell[CellGroupData[{
Cell[1593, 46, 669, 21, 46, "Input",ExpressionUUID->"fd6a88ed-d728-44d1-85b9-d80478a73835"],
Cell[2265, 69, 1012, 25, 77, "Output",ExpressionUUID->"6c0a5fd9-c58d-4b2b-a93a-81024cf258fb"]
}, Open  ]],
Cell[3292, 97, 319, 8, 88, "Text",ExpressionUUID->"853722f9-ce09-4c79-ab4c-12270dedbf4e"],
Cell[3614, 107, 216, 4, 101, "Section",ExpressionUUID->"3f5dfcdf-14b6-489a-bc52-f7bb2428b055"],
Cell[CellGroupData[{
Cell[3855, 115, 337, 5, 63, "Section",ExpressionUUID->"fda42f80-74e0-452c-bdd2-b6effa0d3a53"],
Cell[CellGroupData[{
Cell[4217, 124, 1038, 25, 78, "Input",ExpressionUUID->"80b1b50b-8123-43aa-a9ef-b86add8422db"],
Cell[5258, 151, 421, 10, 41, "Message",ExpressionUUID->"ab8db0fe-9e00-4807-a824-22650a0b3bb1"],
Cell[5682, 163, 421, 10, 41, "Message",ExpressionUUID->"a0ec6f3b-d0b3-4853-af52-3a20d80a37d4"],
Cell[6106, 175, 1889, 57, 87, "Output",ExpressionUUID->"e6a72c22-e516-4d5b-b33b-56e4638021bc"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[8044, 238, 329, 5, 86, "Section",ExpressionUUID->"239db909-ef68-400c-a3b1-f7ff450b449f"],
Cell[CellGroupData[{
Cell[8398, 247, 1045, 24, 78, "Input",ExpressionUUID->"1f6e2257-d5d6-4e62-babc-1730ee96e56a"],
Cell[9446, 273, 4164, 129, 313, "Output",ExpressionUUID->"449cd38a-4355-4153-b1fc-6e4023d7ff41"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[13659, 408, 263, 4, 86, "Section",ExpressionUUID->"552822cc-57ec-46a7-bce7-05be406f3980"],
Cell[CellGroupData[{
Cell[13947, 416, 869, 22, 78, "Input",ExpressionUUID->"10edea20-ddb2-4c31-b5f0-894093e8a865"],
Cell[14819, 440, 646, 14, 41, "Message",ExpressionUUID->"3e373af9-0966-440c-8fa5-883b2fb1a593"],
Cell[15468, 456, 646, 14, 41, "Message",ExpressionUUID->"8074ea3f-c1af-442e-b213-a02a16a86144"],
Cell[16117, 472, 646, 14, 41, "Message",ExpressionUUID->"180b7458-3c84-4f2d-bb81-ef14eb5dbd9c"],
Cell[16766, 488, 646, 13, 41, "Message",ExpressionUUID->"77799151-55f1-4e42-b558-63dc6506af7b"],
Cell[17415, 503, 4893, 142, 314, "Output",ExpressionUUID->"ed552f91-2871-4bab-a69e-f1da65784144"]
}, Open  ]],
Cell[22323, 648, 623, 11, 135, "Text",ExpressionUUID->"5afbdf49-b8c5-4209-914b-1674e53cf21b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[22983, 664, 211, 4, 101, "Section",ExpressionUUID->"9ce08758-9c0f-45f2-90e3-e8f3b7f28250"],
Cell[CellGroupData[{
Cell[23219, 672, 2038, 45, 78, "Input",ExpressionUUID->"4747573b-aa3f-41d8-bb6f-161a826d00bd"],
Cell[25260, 719, 27669, 516, 313, "Output",ExpressionUUID->"67ab3557-a397-4ac6-bbcf-7de88dfa6181"]
}, Open  ]]
}, Open  ]]
}
]
*)

